Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(443)

Unified Diff: components/search/search.h

Issue 1551433002: Switch to standard integer types in components/, part 3 of 4. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: more Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/search/search.h
diff --git a/components/search/search.h b/components/search/search.h
index 2ce62047b68cef2597071108e4bba200a1b24c08..3907f85c28f0613289bceec26cbe5344284109c2 100644
--- a/components/search/search.h
+++ b/components/search/search.h
@@ -5,11 +5,12 @@
#ifndef COMPONENTS_SEARCH_SEARCH_H_
#define COMPONENTS_SEARCH_SEARCH_H_
+#include <stdint.h>
+
#include <string>
#include <utility>
#include <vector>
-#include "base/basictypes.h"
#include "base/strings/string16.h"
#include "base/strings/string_split.h"
@@ -28,7 +29,7 @@ bool IsInstantExtendedAPIEnabled();
// Returns the value to pass to the &espv CGI parameter when loading the
// embedded search page from the user's default search provider. Returns 0 if
// the Instant Extended API is not enabled.
-uint64 EmbeddedSearchPageVersion();
+uint64_t EmbeddedSearchPageVersion();
// Type for a collection of experiment configuration parameters.
typedef base::StringPairs FieldTrialFlags;
@@ -49,12 +50,12 @@ std::string GetStringValueForFlagWithDefault(const std::string& flag,
const std::string& default_value,
const FieldTrialFlags& flags);
// Given a FieldTrialFlags object, returns the uint64 value of the provided
// flag.
// Exposed for testing only.
-uint64 GetUInt64ValueForFlagWithDefault(const std::string& flag,
- uint64 default_value,
- const FieldTrialFlags& flags);
+uint64_t GetUInt64ValueForFlagWithDefault(const std::string& flag,
+ uint64_t default_value,
+ const FieldTrialFlags& flags);
// Given a FieldTrialFlags object, returns the bool value of the provided flag.
// Exposed for testing only.
« no previous file with comments | « components/scheduler/test/lazy_scheduler_message_loop_delegate_for_tests.h ('k') | components/search/search.cc » ('j') | no next file with comments »
@@ -49,12 +50,12 @@ std::string GetStringValueForFlagWithDefault(const std::string& flag,
const std::string& default_value,
const FieldTrialFlags& flags);
-// Given a FieldTrialFlags object, returns the uint64 value of the provided
+// Given a FieldTrialFlags object, returns the uint64_t value of the provided
// flag.
// Exposed for testing only.

Powered by Google App Engine
This is Rietveld 408576698